package com.ibm.commerce.telesales.ATPT.tracing;

/*
  *-----------------------------------------------------------------
  * Licensed Materials - Property of IBM
  *
  * WebSphere Commerce
  *
  * (C) Copyright IBM Corp. 2009 All Rights Reserved.
  *
  * US Government Users Restricted Rights - Use, duplication or
  * disclosure restricted by GSA ADP Schedule Contract with
  * IBM Corp.
  *-----------------------------------------------------------------
  */
//*---------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been  
//* thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its 
//* reliability, serviceability or functionality.  
//*
//* This sample may include the names of individuals, companies, brands 
//* and products in order to illustrate concepts as completely as 
//* possible.  All of these names
//* are fictitious and any similarity to the names and addresses used by 
//* actual persons 
//* or business enterprises is entirely coincidental.
//*---------------------------------------------------------------------


import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.core.runtime.Status;
import org.osgi.framework.BundleContext;



import java.lang.reflect.InvocationTargetException;
import java.text.MessageFormat;
import java.util.*;

/**
 * The main plugin class to be used in the desktop.
 */
public class ATPTTracingPlugin extends Plugin {
	//The shared instance.
	private static ATPTTracingPlugin plugin;
	//Resource bundle.
	private ResourceBundle resourceBundle_;
	
	/** Signifies whether DEBUG mode is enabled. */
	public static boolean DEBUG = false;

	/** Signifies whether DEBUG logging is enabled. */
	public static boolean DEBUG_LOGGING = false;

	/**
	 * The constructor.
	 */
	public ATPTTracingPlugin() {
		super();
		plugin = this;
		try {
			resourceBundle_ = ResourceBundle.getBundle("com.ibm.commerce.telesales.ATPT.tracing.ATPTPluginResources");
		} catch (MissingResourceException x) {
			resourceBundle_ = null;
		}
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	     // Setup debugging options
        DEBUG = isDebugging();
        if (DEBUG) {
            DEBUG_LOGGING = "true".equalsIgnoreCase(Platform.getDebugOption("com.ibm.commerce.telesales.ATPT.tracing/debug/logging")); //$NON-NLS-1$ //$NON-NLS-2$
        }
        //DEBUG_LOGGING= true;
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static ATPTTracingPlugin getDefault() {
		return plugin;
	}


	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle_;
	}
	
	/**
     * Returns this plug-in instance.
     *
     * @return The single instance of this plug-in runtime class.
     */
    public static ATPTTracingPlugin getPlugin() {
        return plugin;
    }


	/**
	 * Convenience method which returns the unique identifier of this plugin.
     * 
     * @see org.eclipse.core.runtime.Plugin#getBundle()
     * @see org.osgi.framework.Bundle#getSymbolicName()
	 */
	public static String getUniqueIdentifier() {
		if (getPlugin() == null || getPlugin().getBundle() == null) {
			// If the default instance is not yet initialized,
			// return a static identifier. This identifier must
			// match the plugin id defined in plugin.xml
			return "com.ibm.commerce.telesales.core"; //$NON-NLS-1$
		}

        return getPlugin().getBundle().getSymbolicName();
	}
	/**
	 * Should be used to get a text string from a resource bundle.  Handles
	 * "MissingResourceExceptions" by returning the "key" to the caller as the
	 * requested string.
	 *
	 * @param key  the key to search for in the resource bundle
	 * @return  formatted message string
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = ATPTTracingPlugin.getDefault().getResourceBundle();
		if (bundle != null) {
			try {
				String text = bundle.getString(key);
				return text;
			}
			catch (MissingResourceException mre) {
				// default actions is to return key, which is OK
			    return key;
			}
		}

		return key;
	}
	
	/**
	 * Logs a status message.
	 * @param status  The status message to log.
	 */
	public static void log(IStatus status) {
		getPlugin().getLog().log(status);
	}

	/**
	 * Logs an error message.
	 * @param message  The error message to log.
	 */
	public static void logErrorMessage(String message) {
		log(new Status(IStatus.ERROR, getUniqueIdentifier(), IStatus.ERROR, message, null));
	}

	/**
	 * Logs an exception.
	 * @param exception  The exception to log.
	 * @param title  The title of the error dialog.
	 * @param message  The descriptive message to display within the error dialog.
	 */
	public static void logException(Throwable exception, final String title, String message) {
		if (exception instanceof InvocationTargetException) {
			exception = ((InvocationTargetException) exception).getTargetException();
		}
        
		IStatus status = null;
		if (exception instanceof CoreException) {
			status = ((CoreException) exception).getStatus();
		}
		else {
			if (message == null) {
				message = exception.getMessage();
			}
			if (message == null) {
				message = exception.toString();
			}

			status = new Status(IStatus.ERROR, getUniqueIdentifier(), IStatus.OK, message, exception);
		}
        
		getPlugin().getLog().log(status);

		
	}

	/**
	 * Log an exception.
	 * @param exception  The exception to log.
	 */
	public static void logException(Throwable exception) {
		logException(exception, null, null);
	}

	/**
	 * Log an exception.
	 * @param exception  The exception to log.
	 */
	public static void log(Throwable exception) {
		if (exception instanceof InvocationTargetException) {
			exception = ((InvocationTargetException) exception).getTargetException();
		}

		IStatus status = null;
		if (exception instanceof CoreException) {
			status = ((CoreException) exception).getStatus();
		}
		else {
			status = new Status(IStatus.ERROR, getUniqueIdentifier(), IStatus.ERROR, exception.getMessage(), exception);
		}

		log(status);
	}
	
	/**
	 * Gets a text string from a resource bundle.  Handles
	 * "MissingResourceExceptions" by returning the "key" to the caller as the
	 * requested string.
	 *
	 * @param key  the key to search for in the resource bundle
	 * @param args  an array of Strings to be added into the message text
	 * @return  formatted message string
	 */
	public static String getFormattedMessage(String key, String[] args) {
		String text = getResourceString(key);
		return MessageFormat.format(text, args);
	}

}
